==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager.md <==
# AmazonElasticBlockStoreAmazonDataLifecycleManager


```text
aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager
```

```text
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')
```



| Illustration | AmazonElasticBlockStoreAmazonDataLifecycleManager | AmazonElasticBlockStoreAmazonDataLifecycleManagerCard | AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager.png) | ![illustration for AmazonElasticBlockStoreAmazonDataLifecycleManager](../../../aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager.Local.png) | ![illustration for AmazonElasticBlockStoreAmazonDataLifecycleManagerCard](../../../aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManagerCard.Local.png) | ![illustration for AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup](../../../aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup.Local.png) |




## AmazonElasticBlockStoreAmazonDataLifecycleManager

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManager
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManager('AmazonElasticBlockStoreAmazonDataLifecycleManager', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManager
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManager('AmazonElasticBlockStoreAmazonDataLifecycleManager', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager', 'an optional tech label')
@enduml
```

## AmazonElasticBlockStoreAmazonDataLifecycleManagerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManagerCard
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManagerCard('AmazonElasticBlockStoreAmazonDataLifecycleManagerCard', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManagerCard
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManagerCard('AmazonElasticBlockStoreAmazonDataLifecycleManagerCard', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager Card', 'an optional description')
@enduml
```

## AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup('AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup('AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager.md <==
# AmazonElasticBlockStoreAmazonDataLifecycleManager


```text
aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager
```

```text
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')
```



| Illustration | AmazonElasticBlockStoreAmazonDataLifecycleManager | AmazonElasticBlockStoreAmazonDataLifecycleManagerCard | AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager.png) | ![illustration for AmazonElasticBlockStoreAmazonDataLifecycleManager](../../../aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager.Local.png) | ![illustration for AmazonElasticBlockStoreAmazonDataLifecycleManagerCard](../../../aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManagerCard.Local.png) | ![illustration for AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup](../../../aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup.Local.png) |




## AmazonElasticBlockStoreAmazonDataLifecycleManager

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManager
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManager('AmazonElasticBlockStoreAmazonDataLifecycleManager', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManager
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManager('AmazonElasticBlockStoreAmazonDataLifecycleManager', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager', 'an optional tech label')
@enduml
```

## AmazonElasticBlockStoreAmazonDataLifecycleManagerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManagerCard
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManagerCard('AmazonElasticBlockStoreAmazonDataLifecycleManagerCard', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManagerCard
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManagerCard('AmazonElasticBlockStoreAmazonDataLifecycleManagerCard', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager Card', 'an optional description')
@enduml
```

## AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup('AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup
include('aws-q3-2021/Resource/Storage/AmazonElasticBlockStoreAmazonDataLifecycleManager')

' renders the element
AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup('AmazonElasticBlockStoreAmazonDataLifecycleManagerGroup', 'Amazon Elastic Block Store Amazon Data Lifecycle Manager Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
